@@ -148,7 +148,7 @@ class Code:
         warez.clone_repo(bare_repo, working_repo)  # TODO shallow clone?
         post_receive_hook = bare_repo / "hooks/post-receive"
         with post_receive_hook.open("w") as fp:
-            fp.write("git -C $PWD/../working --git-dir=.git pull --rebase")
+            fp.write("#!/bin/sh\n\ngit -C $PWD/../working --git-dir=.git pull --rebase")
         subprocess.run(["chmod", "775", post_receive_hook])
         subprocess.run(["chgrp", "www-data", bare_repo, working_repo, "-R"])
         subprocess.run(["chmod", "g+w", bare_repo, working_repo, "-R"])
@@ -163,7 +163,7 @@ class Project:
         """Return details about the project."""
         return app.view.project(
             project,
-            warez.Repo(code_dir / project / "source.git"),
+            warez.Repo(code_dir / project / "working"),
             app.model.get_package_versions(project),
         )
 
